# Supplementary R code
# Synergistic effects of mutualistic rhizobacteria counteract virus-induced
# suppression of indirect plant defenses in soybean.

# Hannier Pulido1, Kerry E. Mauck2, Consuelo M. De Moraes1, Mark C. Mescher1*
    
# *Correspondence and requests for materials should be addressed to Mark C. Mescher, 
# e-mail: mescher@usys.ethz.ch


## ----Load R required packages--------------------------------------------
require(MCMCglmm)
require(dplyr)
require(vegan)
require(varSelRF)
require(limma)



####################################################
# 1. Analysis of Y-tube foraging assays
####################################################

# Using the multinomial family so taking as response the number of wasps
# choosing the treatment (# of successes) and the number of wasps choosing the
# control (n-successes)

# Read data
load("data/raw/Ytube_20190418.RData")

# ----Preliminary tests (Table S1.2)---------------------------------------
# Define priors
prior1 <- list(R = list(V = 1, fix=1, nu = 0.002))

## GLMM for Damaged vs Undamaged (preliminary test)
set.seed(2019)
pre1.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, data = pre1, 
                    family = "multinomial2", prior = prior1, nitt = 100000, pr = TRUE, verbose = FALSE)


## GLMM for Damaged vs Empty (preliminary test)
set.seed(2019)
pre2.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, data = pre2, 
                    family = "multinomial2", prior = prior1, nitt = 100000, pr = TRUE, verbose = FALSE)


## GLMM for Undamaged vs Empty (preliminary test)
set.seed(2019)
pre3.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, data = pre3, 
                    family = "multinomial2", prior = prior1, nitt = 100000, pr = TRUE, verbose = FALSE)


# ----Main tests (Table S1.2) ------------------------------------------------
# Define priors
prior2 <- list(R = list(V = 1, nu=0.002),
               G=list(G1=list(V=1, nu=0),
                      G2=list(V=1, nu=0)))

## GLMM for Bj+Da-Uninfected vs Control-Uninfected
set.seed(2019)
H1.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, random = ~ Day + Run, data = H1, 
                  family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Da-Uninfected vs Control-Uninfected
set.seed(2019)
H2.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, random = ~ Day + Run, data = H2, 
                  family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Bj-Uninfected vs Control-Uninfected
set.seed(2019)
H3.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, random = ~ Day + Run, data = H3, 
                  family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Bj+Da-Uninfected vs Bj-Uninfected
set.seed(2019)
H4.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, random = ~ Day + Run, data = H4, 
                  family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)



## GLMM for Bj+Da-Infected vs Control-Infected
set.seed(2019)
I1.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, random = ~ Day + Run, data = I1, 
                  family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Da-Infected vs Control-Infected
set.seed(2019)
I2.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, random = ~ Day+Run, data = I2, 
                  family = "multinomial2", prior = prior3, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Bj-Infected vs Control-Infected
set.seed(2019)
I3.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, random = ~ Day + Run, data = I3, 
                  family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Bj+Da-Infected vs Bj-Infected
set.seed(2019)
I4.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, random = ~ Day + Run, data = I4, 
                  family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)



## GLMM for Bj+Da-Uninfected vs Bj+Da-Infected
set.seed(2019)
M1.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, random = ~ Day + Run, data = M1, 
                  family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Control-Uninfected vs Control-Infected
set.seed(2019)
M2.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ 1, random = ~ Day + Run, data = M2, 
                  family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)


# ----Bayesian GLMM for pair-wise comparisons tested statistically -------

## BjDa-Uninfected vs Da-Uninfected
H1.H2 <- bind_rows(H1, H2) %>% 
    mutate(choice1 = factor(choice1, levels = c("Da", "BjDa")))
set.seed(2019)
H1.H2.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ choice1, random = ~ Day + Run, data = H1.H2, 
                     family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)

## BjDa-Uninfected vs Bj-Uninfected
H1.H3 <- bind_rows(H1, H3) %>% 
    mutate(choice1 = factor(choice1, levels = c("Bj", "BjDa")))
set.seed(2019)
H1.H3.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ choice1, random = ~ Day + Run, data = H1.H3, 
                     family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)


## BjDa-Infected vs Bj-Infected
I1.I2 <- bind_rows(I1, I2) %>% 
    mutate(choice1 = factor(choice1, levels = c("Da", "BjDa")))
set.seed(2019)
I1.I2.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ choice1, random = ~ Day + Run, data = I1.I2, 
                     family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)

## BjDa-Infected vs Bj-Infected
I1.I3 <- bind_rows(I1, I3) %>% 
    mutate(choice1 = factor(choice1, levels = c("Bj", "BjDa")))
set.seed(2019)
I1.I3.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ choice1, random = ~ Day + Run, data = I1.I3, 
                     family = "multinomial2", prior = prior2, nitt = 100000, pr = TRUE, verbose = FALSE)


# ----Bayesian GLMM to test fixed and interaction effects (Table S1.3) ----

H.I <- bind_rows(H1, H2, H3, I1, I2, I3) %>% 
    mutate(BPMV = factor(BPMV, levels = c("Uninfected", "Infected")))

## Without virus effect
set.seed(2019)
all.mm <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ -1 + choice1, random = ~ Day + Run, nitt = 100000,
                   family = "multinomial2", data = H.I, prior = prior2, verbose = FALSE, pr = TRUE)

## With virus effect
set.seed(2019)
all.mm2 <- MCMCglmm(cbind(wasp.trt, wasp.control) ~ -1 + choice1:BPMV, random = ~ Day + Run, nitt = 100000,
                    family = "multinomial2", data = H.I, prior = prior2, verbose = FALSE, pr = TRUE)


# ----Residence time (Table S1.4) ----------------------------------------

## Subset for Uninfected
res.u <- res %>% 
    filter(virus %in% "uninfected") %>% 
    droplevels()
## Subset for Infected
res.i <- res %>% 
    filter(virus %in% "Infected") %>% 
    droplevels()


## Set flat priors
prior.t <- list(R = list(V = 1, nu=0),
                G=list(G1=list(V=1, nu=0),
                       G2=list(V=1, nu=0)))

## GLMM for uninfected
set.seed(2019)
res.u.mm <- MCMCglmm(scale(time2) ~ choice, random = ~ Day + plantPair, data = res.u, family = "gaussian", 
                     prior = prior.t, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for infected
set.seed(2019)
res.i.mm <- MCMCglmm(scale(time2) ~ choice, random = ~ Day + plantPair, data = res.i, family = "gaussian", 
                     prior = prior.t, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for interaction between choice and virus
set.seed(2019)
res.mm2 <- MCMCglmm(scale(time2) ~ choice*virus, random = ~ Day + plantPair, data = res, family = "gaussian", 
                    prior = prior.t, nitt = 100000, pr = TRUE, verbose = FALSE)

# Clear memory
rm(list = ls())


####################################################
# 2. Analysis of parasitism assays
####################################################

# Read data
load("data/raw/Parasitism_20190418.RData")

# ----Main tests (Table S1.2) ------------------------------------------------
# Define priors
k <- length(levels(H1$rhizobia))
I <- diag(k-1)
J <- matrix(rep(1, (k-1)^2), c(k-1, k-1))
priors = list(R = list(fix=1, V=(1/k) * (I + J), n = k - 1),
              G = list(G1 = list(V = diag(k - 1), n = k - 1)))

## GLMM for Bj+Da-Uninfected vs Control-Uninfected
set.seed(2019)
H1.mm <- MCMCglmm(cbind(number.of.mummies, number.of.nonparasitized) ~ rhizobia, random = ~ Day, data = H1, 
                  family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Da-Uninfected vs Control-Uninfected
set.seed(2019)
H2.mm <- MCMCglmm(cbind(number.of.mummies, number.of.nonparasitized) ~ rhizobia, random = ~ Day, data = H2, 
                  family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Bj-Uninfected vs Control-Uninfected
set.seed(2019)
H3.mm <- MCMCglmm(cbind(number.of.mummies, number.of.nonparasitized) ~ rhizobia, random = ~ Day, data = H3, 
                  family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Bj+Da-Uninfected vs Bj-Uninfected
set.seed(2019)
H4.mm <- MCMCglmm(cbind(number.of.mummies, number.of.nonparasitized) ~ rhizobia, random = ~ Day, data = H4, 
                  family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)



## GLMM for Bj+Da-Infected vs Control-Infected
set.seed(2019)
I1.mm <- MCMCglmm(cbind(number.of.mummies, number.of.nonparasitized) ~ rhizobia, random = ~ Day, data = I1, 
                  family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Da-Infected vs Control-Infected
set.seed(2019)
I2.mm <- MCMCglmm(cbind(number.of.mummies, number.of.nonparasitized) ~ rhizobia, random = ~ Day, data = I2, 
                  family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Bj-Infected vs Control-Infected
set.seed(2019)
I3.mm <- MCMCglmm(cbind(number.of.mummies, number.of.nonparasitized) ~ rhizobia, random = ~ Day, data = I3, 
                  family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Bj+Da-Infected vs Bj-Infected
set.seed(2019)
I4.mm <- MCMCglmm(cbind(number.of.mummies, number.of.nonparasitized) ~ rhizobia, random = ~ Day, data = I4, 
                  family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)



## GLMM for Bj+Da-Uninfected vs Bj+Da-Infected
set.seed(2019)
M1.mm <- MCMCglmm(cbind(number.of.mummies, number.of.nonparasitized) ~ rhizobia, random = ~ Day, data = M1, 
                  family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)

## GLMM for Control-Uninfected vs Control-Infected
set.seed(2019)
M2.mm <- MCMCglmm(cbind(number.of.mummies, number.of.nonparasitized) ~ rhizobia, random = ~ Day, data = M2, 
                  family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)


# ----Bayesian GLMM for pair-wise comparisons tested statistically -------
# Use proportion of parasitism in rhizobia and in control

# Subset for each pair-wise comparison
H1.rhizobia <- H1 %>% 
    filter(rhizobia %in% "BjDa") %>% 
    select(-c(number.of.mummies, number.of.nonparasitized)) %>% 
    rename(parasitism.rhizobia = parasitism.rate) %>% 
    mutate(parasitism.control = subset(H1, rhizobia %in% "Control", select = parasitism.rate)[,1]) %>% 
    droplevels() 
H2.rhizobia <- H2 %>% 
    filter(rhizobia %in% "Da") %>% 
    select(-c(number.of.mummies, number.of.nonparasitized)) %>% 
    rename(parasitism.rhizobia = parasitism.rate) %>% 
    mutate(parasitism.control = subset(H2, rhizobia %in% "Control", select = parasitism.rate)[,1]) %>% 
    droplevels() 
H3.rhizobia <- H3 %>% 
    filter(rhizobia %in% "Bj") %>% 
    select(-c(number.of.mummies, number.of.nonparasitized)) %>% 
    rename(parasitism.rhizobia = parasitism.rate) %>% 
    mutate(parasitism.control = subset(H3, rhizobia %in% "Control", select = parasitism.rate)[,1]) %>% 
    droplevels() 
I1.rhizobia <- I1 %>% 
    filter(rhizobia %in% "BjDa") %>% 
    select(-c(number.of.mummies, number.of.nonparasitized)) %>% 
    rename(parasitism.rhizobia = parasitism.rate) %>% 
    mutate(parasitism.control = subset(I1, rhizobia %in% "Control", select = parasitism.rate)[,1]) %>% 
    droplevels() 
I2.rhizobia <- I2 %>% 
    filter(rhizobia %in% "Da") %>% 
    select(-c(number.of.mummies, number.of.nonparasitized)) %>% 
    rename(parasitism.rhizobia = parasitism.rate) %>% 
    mutate(parasitism.control = subset(I2, rhizobia %in% "Control", select = parasitism.rate)[,1]) %>% 
    droplevels() 
I3.rhizobia <- I3 %>% 
    filter(rhizobia %in% "Bj") %>% 
    select(-c(number.of.mummies, number.of.nonparasitized)) %>% 
    rename(parasitism.rhizobia = parasitism.rate) %>% 
    mutate(parasitism.control = subset(I3, rhizobia %in% "Control", select = parasitism.rate)[,1]) %>% 
    droplevels() 


# BjDa-Uninfected vs Da-Uninfected
H1.H2 <- bind_rows(H1.rhizobia, H2.rhizobia) %>% 
    mutate(rhizobia = factor(rhizobia, levels = c("Da", "BjDa")))
set.seed(2019)
H1.H2.mm <- MCMCglmm(cbind(parasitism.rhizobia, parasitism.control) ~ rhizobia, random = ~ Day, data = H1.H2, 
                     family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)

# Bj-Uninfected vs Da-Uninfected
H2.H3 <- bind_rows(H2.rhizobia, H3.rhizobia) %>% 
    mutate(rhizobia = factor(rhizobia, levels = c("Da", "Bj")))
set.seed(2019)
H2.H3.mm <- MCMCglmm(cbind(parasitism.rhizobia, parasitism.control) ~ rhizobia, random = ~ Day, data = H2.H3, 
                     family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)


# BjDa-Infected vs Da-Infected
I1.I2 <- bind_rows(I1.rhizobia, I2.rhizobia) %>% 
    mutate(rhizobia = factor(rhizobia, levels = c("Da", "BjDa")))
set.seed(2019)
I1.I2.mm <- MCMCglmm(cbind(parasitism.rhizobia, parasitism.control) ~ rhizobia, random = ~ Day, data = I1.I2, 
                     family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)


# Bj-Infected vs Da-Infected
I2.I3 <- bind_rows(I2.rhizobia, I3.rhizobia) %>% 
    mutate(rhizobia = factor(rhizobia, levels = c("Da", "Bj")))
set.seed(2019)
I2.I3.mm <- MCMCglmm(cbind(parasitism.rhizobia, parasitism.control) ~ rhizobia, random = ~ Day, data = I2.I3, 
                     family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)


## (BjDa vs Control Uninfected) vs (BjDa vs Control Infected)
H1.I1 <- bind_rows(H1.rhizobia, I1.rhizobia) %>% 
    mutate(Test = factor(Test, levels = c("Uninfected", "Infected")))
set.seed(2019)
H1.I1.mm <- MCMCglmm(cbind(parasitism.rhizobia, parasitism.control) ~ Test, random = ~ Day, data = H1.I1, 
                     family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)
summary(H1.I1.mm)

# Da-Uninfected vs Da-Infected
H2.I2 <- bind_rows(H2.rhizobia, I2.rhizobia) %>% 
    mutate(Test = factor(Test, levels = c("Uninfected", "Infected")))
set.seed(2019)
H2.I2.mm <- MCMCglmm(cbind(parasitism.rhizobia, parasitism.control) ~ Test, random = ~ Day, data = H2.I2, 
                     family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)

# Bj-Uninfected vs Bj-Infected
H3.I3 <- bind_rows(H3.rhizobia, I3.rhizobia) %>% 
    mutate(Test = factor(Test, levels = c("Uninfected", "Infected")))
set.seed(2019)
H3.I3.mm <- MCMCglmm(cbind(parasitism.rhizobia, parasitism.control) ~ Test, random = ~ Day, data = H3.I3, 
                     family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)

# All-Uninfected vs All-Infected
H.I <- bind_rows(H1.rhizobia, H2.rhizobia, H3.rhizobia, I1.rhizobia, I2.rhizobia, I3.rhizobia) %>% 
    mutate(Test = factor(Test, levels = c("Uninfected", "Infected")))
set.seed(2019)
H.I.mm <- MCMCglmm(cbind(parasitism.rhizobia, parasitism.control) ~ Test, random = ~ Day, data = H.I, 
                   family = "multinomial2", prior = priors, nitt = 100000, pr = TRUE, verbose = FALSE)


# ----Bayesian GLMM to test fixed and interaction effects (Table S1.5) ----
# Define priors
prior2 <- list(R = list(V = 1, fix=1),
               G=list(G1=list(V=1, nu=0)))

# Without virus effect
set.seed(2019)
all.mm <- MCMCglmm(cbind(parasitism.rhizobia, parasitism.control) ~ -1 + rhizobia, random = ~Day, nitt=100000,
                   family = "multinomial2", data = H.I, prior = prior2, verbose = FALSE, pr = TRUE)

# With virus effect
set.seed(2019)
all.mm2 <- MCMCglmm(cbind(parasitism.rhizobia, parasitism.control) ~ -1 + (rhizobia+Test)^2, random = ~Day, nitt=100000,
                    family = "multinomial2", data = H.I, prior = prior2, verbose = FALSE, pr = TRUE)

# Clear memory
rm(list = ls())


####################################################
# 3. Analysis plant volatiles
####################################################
# Read data
load("data/raw/voc_20190418.RData")

# ----PERMANOVA (Table S1.6)--------------------------------------------
# Run the permanova model
Y3 <- voc.publication[, 7:ncol(voc.publication)]
set.seed(1305)
per.voc <- adonis(Y3 ~ Bj * Da * BjDa * BPMV, data = voc.publication, 
                   method = "euclidean", sqrt.dist = TRUE, permutations = 999)


# ----Random Forest-----------------------------------------------------
# Set clusters for parallel computing
forkCL <- makeCluster (4)
clusterSetRNGStream(forkCL, iseed = 123)
clusterEvalQ(forkCL, library(varSelRF))

# Uninfected vs Infected
set.seed(2019)
vsb.rf1 <- varSelRFBoot(voc.publication[, 7:ncol(voc.publication)], voc.publication[, 2], 
                        bootnumber = 200, ntree = 3000,
                        usingCluster = TRUE,
                        TheCluster = forkCL)
# Returns error rate
mean(vsb.rf1$all.data.randomForest$err.rate[,"OOB"])
# Returns best compounds
vsb.rf1$all.data.vars


# BjDa vs. the rest (Control, Bj and Da) 
# Sample identity of the rest was masked compared to samples from BjDa
voc2 <- voc.publication %>% 
    mutate(rhi2 = ifelse(rhizobia == "BjDa", "BjDa", "rest")) %>% 
    filter(bpmv %in% "uninfected") %>% 
    droplevels()


set.seed(2019)
vsb.rf2 <- varSelRFBoot(voc2[, 7:25], as.factor(voc2$rhi2),
                         bootnumber = 200, ntree = 3000,
                         usingCluster = TRUE,
                         TheCluster = forkCL)

# Returns error rate
mean(vsb.rf2$all.data.randomForest$err.rate[,"OOB"])
# Returns best compounds
vsb.rf2$all.data.vars



# ----Multiple linear models--------------------------------------------
# Uninfected vs Infected
## Transpose database
voc2.t <- t(scale(Y3))
rownames(voc2.t) <- colnames(Y3)
colnames(voc2.t) <- voc.publication$bpmv

## Make contrasts and design for conditions
voc2.design <-model.matrix(~ bpmv-1, data = voc.publication)
colnames(voc2.design) <- c("uninfected", "Infected")
voc2.cm <- makeContrasts(Infected-uninfected, levels = voc2.design)

## Ordinary fit
voc2.fit <- lmFit(voc2.t, voc2.design)
voc2.fit2 <- contrasts.fit(voc2.fit, voc2.cm)
voc2.fit3 <- eBayes(voc2.fit2)

## Get significance test for compounds
voc2.cm1 <- topTable(voc2.fit3, number = Inf, coef = 1, sort.by = "none")[,c("t", "P.Value")]
voc2.cm1

# rhizobacteria comparisons
## Transpose databases
voc.t <- t(scale(Y3))
rownames(voc.t) <- colnames(Y3)
colnames(voc.t) <- voc.publication$rhizobia

## Make contrasts and design for conditions
voc.design <- model.matrix(~ rhizobia:bpmv -1, data = voc.publication)

colnames(voc.design) <- c("control.uninfected", "Bj.uninfected", "BjDa.uninfected", 
                          "Da.uninfected", "control.infected", "Bj.infected", 
                          "BjDa.infected", "Da.infected")
voc.cm <- makeContrasts(BjDa.uninfected-control.uninfected, BjDa.uninfected-Bj.uninfected, 
                        BjDa.uninfected-Da.uninfected, 
                        levels = voc.design)

## Ordinary fit
voc.fit <- lmFit(voc.t, voc.design)
voc.fit2 <- contrasts.fit(voc.fit, voc.cm)
voc.fit3 <- eBayes(voc.fit2)

## Get significance test for compounds in BjDa uninfected vs Control uninfected 
voc.cm1 <- topTable(voc.fit3, number = Inf, coef = 1, sort.by = "none")[,c("t", "P.Value")]
voc.cm1

## Get significance test for compounds in BjDa uninfected vs Bj uninfected
voc.cm2 <- topTable(voc.fit3, number = Inf, coef = 2, sort.by = "none")[,c("t", "P.Value")]
voc.cm2

## Get significance test for compounds in BjDa uninfected vs Da uninfected
voc.cm3 <- topTable(voc.fit3, number = Inf, coef = 3, sort.by = "none")[,c("t", "P.Value")]
voc.cm3


# Clear memory
rm(list = ls())


####################################################
# 4. Analysis of plant biomass
####################################################
load("data/raw/shoot_nod_bpmvSymptoms_20190422.RData")

# Set priors
prior1 <- list(R = list(V = 1, nu = 0))

# GLMM for rhizobia
set.seed(2019)
shoot.mm <- MCMCglmm(dryWeight ~ trt, data = shoot, family = "gaussian", 
                     prior = prior1, nitt = 100000, pr = TRUE, verbose = FALSE)

# GLMM for rhizobia*virus interaction
set.seed(2019)
shoot.mm2 <- MCMCglmm(dryWeight ~ trt*virus, data = shoot, family = "gaussian", 
                      prior = prior1, nitt = 100000, pr = TRUE, verbose = FALSE)


####################################################
# 5. Analysis of nodulation
####################################################
# GLMM for rhizobia
set.seed(2019)
nod.mm <- MCMCglmm(nodulesWeight_scaled ~ trt, data = nod, family = "gaussian", 
                   prior = prior1, nitt = 100000, pr = TRUE, verbose = FALSE)

# GLMM for rhizobia*virus interaction
set.seed(2019)
nod.mm2 <- MCMCglmm(nodulesWeight_scaled ~ trt*virus, data = nod, family = "gaussian", 
                    prior = prior1, nitt = 100000, pr = TRUE, verbose = FALSE)


####################################################
# 6. Analysis of BPMV symptoms
####################################################

set.seed(2019)
# glmm model for "mild symptoms" = 1, 2, 3
bpmv.mm <- MCMCglmm(I(as.factor(InfectedSeverity) == c("1", "2", "3")) ~ trt, 
                    data = symp, family = "categorical",
                    nitt = 100000, pr = TRUE, verbose = FALSE)

# Clear memory
rm(list = ls())

####################################################
# End of the run
####################################################
